summaryrefslogtreecommitdiffstats
path: root/kdejava/koala/org/kde/koala/KServiceType.java
diff options
context:
space:
mode:
Diffstat (limited to 'kdejava/koala/org/kde/koala/KServiceType.java')
-rw-r--r--kdejava/koala/org/kde/koala/KServiceType.java20
1 files changed, 10 insertions, 10 deletions
diff --git a/kdejava/koala/org/kde/koala/KServiceType.java b/kdejava/koala/org/kde/koala/KServiceType.java
index f22c982a..3594633f 100644
--- a/kdejava/koala/org/kde/koala/KServiceType.java
+++ b/kdejava/koala/org/kde/koala/KServiceType.java
@@ -3,9 +3,9 @@ package org.kde.koala;
import org.kde.qt.Qt;
import org.kde.qt.QtSupport;
-import org.kde.qt.QDataStream;
+import org.kde.qt.TQDataStream;
import java.util.ArrayList;
-import org.kde.qt.QVariant;
+import org.kde.qt.TQVariant;
/**
@@ -59,11 +59,11 @@ public class KServiceType extends KSycocaEntry {
The stream must already be positionned at the correct offset
@short
*/
- public KServiceType(QDataStream _str, int offset) {
+ public KServiceType(TQDataStream _str, int offset) {
super((Class) null);
newKServiceType(_str,offset);
}
- private native void newKServiceType(QDataStream _str, int offset);
+ private native void newKServiceType(TQDataStream _str, int offset);
/**
Returns the icon associated with this service type. Some
derived classes offer special functions which take for
@@ -131,7 +131,7 @@ public class KServiceType extends KSycocaEntry {
@short Returns the requested property.
*/
- public native QVariant property(String _name);
+ public native TQVariant property(String _name);
/**
Returns the list of all properties of this service type.
@return the list of properties
@@ -155,17 +155,17 @@ public class KServiceType extends KSycocaEntry {
*/
public native int propertyDef(String _name);
public native ArrayList propertyDefNames();
// const QMap<QString, QVariant::Type>& propertyDefs(); >>>> NOT CONVERTED
/**
Save ourselves to the data stream.
@short
*/
- public native void save(QDataStream arg1);
+ public native void save(TQDataStream arg1);
/**
Load ourselves from the data stream.
@short
*/
- public native void load(QDataStream arg1);
+ public native void load(TQDataStream arg1);
/**
Pointer to parent serice type
@short
@@ -190,7 +190,7 @@ public class KServiceType extends KSycocaEntry {
@short Returns a pointer to the servicetype '_name' or 0L if the service type is unknown.
*/
- // KServiceType::Ptr serviceType(const QString& arg1); >>>> NOT CONVERTED
+ // KServiceType::Ptr serviceType(const TQString& arg1); >>>> NOT CONVERTED
/**
Returns all services supporting the given servicetype name.
This doesn't take care of the user profile.
@@ -201,7 +201,7 @@ public class KServiceType extends KSycocaEntry {
@short Returns all services supporting the given servicetype name.
*/
- // KService::List offers(const QString& arg1); >>>> NOT CONVERTED
+ // KService::List offers(const TQString& arg1); >>>> NOT CONVERTED
/**
Returns a list of all the supported servicetypes. Useful for
showing the list of available servicetypes in a listbox,
@@ -155,17 +155,17 @@ public class KServiceType extends KSycocaEntry {
public native int propertyDef(String _name);
public native ArrayList propertyDefNames();
- // const QMap<QString, QVariant::Type>& propertyDefs(); >>>> NOT CONVERTED
+ // const TQMap<TQString, TQVariant::Type>& propertyDefs(); >>>> NOT CONVERTED
/**
Save ourselves to the data stream.